Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3947)

Unified Diff: chrome/common/safe_browsing/client_model.proto

Issue 7866011: Switch to the new client-side phishing model that uses Murmurhash for word hashes. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix compile problems and add another test Created 9 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | chrome/renderer/safe_browsing/murmurhash3_util.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/safe_browsing/client_model.proto
diff --git a/chrome/common/safe_browsing/client_model.proto b/chrome/common/safe_browsing/client_model.proto
index 622ba8f8fff67cebf48700d7860dc6687718d319..6a1a912d5f56a13f9f6cf1e1c26c2dd3f45bf76d 100644
--- a/chrome/common/safe_browsing/client_model.proto
+++ b/chrome/common/safe_browsing/client_model.proto
@@ -60,11 +60,12 @@ message ClientSideModel {
// as lowercase UTF-8 strings.
repeated int32 page_term = 3;
- // List of indexes that point to the hashed page words. The page words
- // correspond to all words that appear in page terms. If the term
- // "one two" is in the list of page terms then "one" and "two" will be
- // in the list of page words.
- repeated int32 page_word = 4;
+ // List of hashed page words. The page words correspond to all words that
+ // appear in page terms. If the term "one two" is in the list of page terms
+ // then "one" and "two" will be in the list of page words. For page words
+ // we don't use SHA256 because it is too expensive. We use MurmurHash3
+ // instead. See: http://code.google.com/p/smhasher.
+ repeated fixed32 page_word = 4;
// Page terms in page_term contain at most this many page words.
required int32 max_words_per_term = 5;
@@ -84,4 +85,7 @@ message ClientSideModel {
optional int32 size = 2 [default = 128];
};
repeated IPSubnet bad_subnet = 7;
+
+ // Murmur hash seed that was used to hash the page words.
+ optional fixed32 murmur_hash_seed = 8;
}
« no previous file with comments | « chrome/chrome_tests.gypi ('k') | chrome/renderer/safe_browsing/murmurhash3_util.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698